##  Allocate Application Cost
For widely used applications, you get better cost insights when you allocate costs to the main cost-driving business capabilities and organizations. The total cost of ownership calculation will automatically take into account existing relations and allocate costs accordingly.
Cost allocation is calculated automatically. It’s based on either the support for business capabilities or the usage type for organizations:
  * No leading business capability / no owner (organization): Costs are divided equally between all related business capabilities, same treatment of support type supporting and no support type assignment
  * 1 leading business capability / 1 owner (organization): Costs are assigned to this business capability
  * More than 1 leading business capabilities / more than 1 owner (organization): Costs are divided equally between all leading business capabilities


![Screenshot of fact sheet details showing the business capabilities details with a focus on the support type values](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loiodc78646ae6c1420e95f46fc4119c2044_HiRes.png)
![Screenshot of fact sheet details showing the used applications with a focus on the usage type values](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio767399e0aecc4e32b72a014ab249c5d0_HiRes.png)
